@@ -7,7 +7,7 @@ use {
 
 #[derive(Accounts)]
 #[instruction(
-    instruction_data: InstructionData,
+    ix: InstructionData,
     exec_at: i64, 
     stop_at: i64,
     recurr: i64,
@@ -16,10 +16,17 @@ use {
 pub struct TaskCreate<'info> {
     #[account(
         address = sysvar::clock::ID,
-        constraint = exec_at >= clock.unix_timestamp @ ErrorCode::InvalidExecAtStale
+        constraint = exec_at >= clock.unix_timestamp - 10 @ ErrorCode::InvalidExecAtStale
     )]
     pub clock: Sysvar<'info, Clock>,
 
+    #[account(
+        seeds = [SEED_CONFIG],
+        bump = config.bump,
+        owner = crate::ID,
+    )]
+    pub config: Account<'info, Config>,
+
     #[account(
         mut,
         seeds = [
@@ -44,8 +51,7 @@ pub struct TaskCreate<'info> {
         ],
         bump = bump,
         payer = owner,
-        space = 8 + size_of::<Task>() + std::mem::size_of_val(&instruction_data),
-        // TODO dont let tasks be scheduled in the past.
+        space = 8 + size_of::<Task>() + borsh::to_vec(&ix).unwrap().len(),
     )]
     pub task: Account<'info, Task>,
 
@@ -55,25 +61,24 @@ pub struct TaskCreate<'info> {
 
 pub fn handler(
     ctx: Context<TaskCreate>,
-    instruction_data: InstructionData,
+    ix: InstructionData,
     exec_at: i64, 
     stop_at: i64,
     recurr: i64,
     bump: u8,
 ) -> ProgramResult {
     // Get accounts.
+    let config = &ctx.accounts.config;
     let daemon = &mut ctx.accounts.daemon;
     let task = &mut ctx.accounts.task;
 
     // Validate the scheduling chronology.
     require!(exec_at <= stop_at, ErrorCode::InvalidChronology);
-
-    // Validate recurrence interval is not negative.
     require!(recurr >= 0, ErrorCode::InvalidRecurrNegative);
+    require!(recurr == 0 || recurr >= config.min_recurr, ErrorCode::InvalidRecurrBelowMin);
 
-    // Validate the daemon is the only required signer on the instruction.
-    // If the instruction has other required signers, we should just fail now.
-    for acc in instruction_data.keys.as_slice() {
+    // Reject the instruction if it has other signers besides the daemon.
+    for acc in ix.accounts.as_slice() {
         require!(
             !acc.is_signer || acc.pubkey == daemon.key(), 
             ErrorCode::InvalidSignatory
@@ -83,7 +88,7 @@ pub fn handler(
     // Initialize task account.
     task.daemon = daemon.key();
     task.id = daemon.task_count;
-    task.instruction_data = instruction_data;
+    task.ix = ix;
     task.status = TaskStatus::Pending;
     task.exec_at = exec_at;
     task.stop_at = stop_at;
