@@ -5,17 +5,29 @@ pub mod state;
 
 use {anchor_lang::prelude::*, instructions::*, state::*};
 
-declare_id!("AUDt6tUdA3eMNjX5pyirrroNLyqupKUnzpeFdsrGBWmv");
+declare_id!("5F5bYKuGwR5xrXr6mCo5wi6zAiSebSM2jzeDA8dwTF6A");
 
 #[program]
 pub mod cronos {
     use super::*;
 
-    pub fn admin_schedule_health_check(
-        ctx: Context<AdminScheduleHealthCheck>,
+    pub fn admin_cancel_task(ctx: Context<AdminCancelTask>) -> ProgramResult {
+        admin_cancel_task::handler(ctx)
+    }
+
+    pub fn admin_create_task(
+        ctx: Context<AdminCreateTask>,
+        ix: InstructionData,
+        exec_at: i64,
+        stop_at: i64,
+        recurr: i64,
         bump: u8,
     ) -> ProgramResult {
-        admin_schedule_health_check::handler(ctx, bump)
+        admin_create_task::handler(ctx, ix, exec_at, stop_at, recurr, bump)
+    }
+
+    pub fn admin_reset_health(ctx: Context<AdminResetHealth>) -> ProgramResult {
+        admin_reset_health::handler(ctx)
     }
 
     pub fn config_update_admin(
@@ -25,6 +37,13 @@ pub mod cronos {
         config_update_admin::handler(ctx, new_admin)
     }
 
+    pub fn config_update_min_recurr(
+        ctx: Context<ConfigUpdateMinRecurr>,
+        new_min_recurr: i64,
+    ) -> ProgramResult {
+        config_update_min_recurr::handler(ctx, new_min_recurr)
+    }
+
     pub fn config_update_program_fee(
         ctx: Context<ConfigUpdateProgramFee>,
         new_program_fee: u64,
@@ -88,13 +107,13 @@ pub mod cronos {
 
     pub fn task_create(
         ctx: Context<TaskCreate>,
-        instruction_data: InstructionData,
+        ix: InstructionData,
         exec_at: i64,
         stop_at: i64,
         recurr: i64,
         bump: u8,
     ) -> ProgramResult {
-        task_create::handler(ctx, instruction_data, exec_at, stop_at, recurr, bump)
+        task_create::handler(ctx, ix, exec_at, stop_at, recurr, bump)
     }
 
     pub fn task_execute(ctx: Context<TaskProcess>) -> ProgramResult {
