@@ -14,12 +14,22 @@ pub enum TaskStatus {
     Pending,
 }
 
+impl std::fmt::Display for TaskStatus {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            TaskStatus::Cancelled => write!(f, "cancelled"),
+            TaskStatus::Executed => write!(f, "executed"),
+            TaskStatus::Pending => write!(f, "pending"),
+        }
+    }
+}
+
 #[account]
 #[derive(Debug)]
 pub struct Task {
     pub daemon: Pubkey,
     pub id: u128,
-    pub instruction_data: InstructionData,
+    pub ix: InstructionData,
     pub status: TaskStatus,
     pub exec_at: i64, // Execute at
     pub stop_at: i64, // Stop executing at
@@ -41,7 +51,7 @@ pub struct InstructionData {
     /// Pubkey of the instruction processor that executes this instruction
     pub program_id: Pubkey,
     /// Metadata for what accounts should be passed to the instruction processor
-    pub keys: Vec<AccountMetaData>,
+    pub accounts: Vec<AccountMetaData>,
     /// Opaque data passed to the instruction processor
     pub data: Vec<u8>,
 }
@@ -67,7 +77,7 @@ impl From<Instruction> for InstructionData {
     fn from(instruction: Instruction) -> Self {
         InstructionData {
             program_id: instruction.program_id,
-            keys: instruction
+            accounts: instruction
                 .accounts
                 .iter()
                 .map(|a| AccountMetaData {
@@ -86,7 +96,7 @@ impl From<&InstructionData> for Instruction {
         Instruction {
             program_id: instruction.program_id,
             accounts: instruction
-                .keys
+                .accounts
                 .iter()
                 .map(|a| AccountMeta {
                     pubkey: a.pubkey,
